==> impact-0.0.4.tar.gz: lib/0_Impact_Global/1_Get_Data_SP.dart <==

import 'package:impact/0_Impact_Global/2_Shared_Preference.dart';
import 'package:impact/0_Impact_Global/3_Set_Text_Direction.dart';
import 'package:impact/0_Impact_Global/4_Set_Theme.dart';

ImpactGetDataSP() async {
  ImpactSelectedTheme = await SP_Get(ImpactSelectedTheme.toString(),'ImpactSelectedTheme');
  ImpactSelectedLang = await SP_Get(ImpactSelectedLang.toString(),'ImpactSelectedLang');
  ImpactPageSelectorLoaded = await SP_Get(ImpactPageSelectorLoaded.toString(),'ImpactPageSelectorLoaded');
  ImpactUserID = await SP_Get(ImpactUserID.toString(),'ImpactUserID');
  ImpactUserName = await SP_Get(ImpactUserName.toString(),'ImpactUserName');
  ImpactUserProfilePic = await SP_Get(ImpactUserProfilePic.toString(),'ImpactUserProfilePic');
  ImpactUserPhone = await SP_Get(ImpactUserPhone.toString(),'ImpactUserPhone');
  ImpactUserEmail = await SP_Get(ImpactUserEmail.toString(),'ImpactUserEmail');
  ImpactUserPass = await SP_Get(ImpactUserPass.toString(),'ImpactUserPass');
  ImpactSelectedCountry = await SP_Get(ImpactSelectedCountry.toString(),'ImpactSelectedCountry');
  ImpactSelectedCountryCode = await SP_Get(ImpactSelectedCountryCode.toString(),'ImpactSelectedCountryCode');
  ImpactUserLocation = await SP_Get(ImpactUserLocation.toString(),'ImpactUserLocation');

  if(ImpactSelectedTheme==null || ImpactSelectedTheme=="" || ImpactSelectedTheme.toString()=="null"){
    ImpactSelectedTheme = "Light";
  }

  if(ImpactSelectedLang==null || ImpactSelectedLang=="" || ImpactSelectedLang.toString()=="null"){
    ImpactSelectedLang = "English";
  }

  if(ImpactUserProfilePic==null || ImpactUserProfilePic=="" || ImpactUserProfilePic.toString()=="null"){
    ImpactUserProfilePic = "https://user-images.githubusercontent.com/27860743/64064695-b88dab00-cbfc-11e9-814f-30921b66035f.png";
  }


  ImpactSetTextDirection();
  ImpactSetTheme();
}

==> impact-0.0.5.tar.gz: lib/0_Impact_Global/1_Get_Data_SP.dart <==

import '2_Shared_Preference.dart';
import '3_Set_Text_Direction.dart';
import '4_Set_Theme.dart';

ImpactGetDataSP() async {
  ImpactSelectedTheme = await SP_Get(ImpactSelectedTheme.toString(),'ImpactSelectedTheme');
  ImpactSelectedLang = await SP_Get(ImpactSelectedLang.toString(),'ImpactSelectedLang');
  ImpactPageSelectorLoaded = await SP_Get(ImpactPageSelectorLoaded.toString(),'ImpactPageSelectorLoaded');
  ImpactUserID = await SP_Get(ImpactUserID.toString(),'ImpactUserID');
  ImpactUserName = await SP_Get(ImpactUserName.toString(),'ImpactUserName');
  ImpactUserProfilePic = await SP_Get(ImpactUserProfilePic.toString(),'ImpactUserProfilePic');
  ImpactUserPhone = await SP_Get(ImpactUserPhone.toString(),'ImpactUserPhone');
  ImpactUserEmail = await SP_Get(ImpactUserEmail.toString(),'ImpactUserEmail');
  ImpactUserPass = await SP_Get(ImpactUserPass.toString(),'ImpactUserPass');
  ImpactSelectedCountry = await SP_Get(ImpactSelectedCountry.toString(),'ImpactSelectedCountry');
  ImpactSelectedCountryCode = await SP_Get(ImpactSelectedCountryCode.toString(),'ImpactSelectedCountryCode');
  ImpactUserLocation = await SP_Get(ImpactUserLocation.toString(),'ImpactUserLocation');
  ImpactCoverPicture = await SP_Get(ImpactCoverPicture.toString(),'ImpactCoverPicture');
  ImpactIP     = await SP_Get(ImpactIP.toString(),'ImpactIP');
  ImpactOS = await SP_Get(ImpactOS.toString(),'ImpactDevice');
  ImpactBrand  = await SP_Get(ImpactBrand.toString(),'ImpactBrand');
  ImpactModel  = await SP_Get(ImpactModel.toString(),'ImpactModel');
  ImpactFCM    = await SP_Get(ImpactFCM.toString(),'ImpactFCM');


  if(ImpactSelectedTheme==null || ImpactSelectedTheme=="" || ImpactSelectedTheme.toString()=="null"){
    ImpactSelectedTheme = "Light";
  }

  if(ImpactUserProfilePic==null || ImpactUserProfilePic=="" || ImpactUserProfilePic.toString()=="null"){
    ImpactUserProfilePic = "https://user-images.githubusercontent.com/27860743/64064695-b88dab00-cbfc-11e9-814f-30921b66035f.png";
  }

  if(ImpactCoverPicture==null || ImpactCoverPicture=="" || ImpactCoverPicture.toString()=="null"){
    ImpactCoverPicture = "https://user-images.githubusercontent.com/27860743/64064695-b88dab00-cbfc-11e9-814f-30921b66035f.png";
  }




  ImpactSetTextDirection();
  ImpactSetTheme();
}
